//
//  PaymentViewController.m
//  Payment
//
//  Created by kunii on 10/03/21.
//  Copyright Apple Inc 2010. All rights reserved.
//

#import "PaymentViewController.h"

@implementation PaymentViewController
@synthesize tableView,
			totalAmoutLabel,
			amountTextField,
			enterButton,
			imageView, 
			image, 
			exclusions, 
			paymentDelegate;

/*
	合計金額の計算
*/
-(void)calc {
	int total = 0;
	for (NSNumber* num in exclusions) {
		total += [num intValue];
	}
	totalAmoutLabel.text = [numberFormatter stringFromNumber:[NSNumber numberWithInt:total]];
}


// The designated initializer. Override to perform setup that is required before the view is loaded.
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil {
    if ((self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])) {
		exclusions = [[NSMutableArray alloc] init];
		numberFormatter = [[NSNumberFormatter alloc] init];
		[numberFormatter 
			setNumberStyle:NSNumberFormatterCurrencyStyle];
		[numberFormatter 
			setLocale:[[NSLocale alloc] initWithLocaleIdentifier:@"ja-JP"]];
    }
    return self;
}

//	テーブルービューのスクロールバーをフラッシュ
- (void)viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
	[tableView flashScrollIndicators];
}


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad {
    [super viewDidLoad];
	imageView.image = image;
	tableView.allowsSelection = NO;
	self.navigationItem.rightBarButtonItem = [self editButtonItem];
	amountTextField.delegate = self;
	[tableView reloadData];
	[self calc];
}

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	self.tableView = nil;
	self.totalAmoutLabel = nil;
	self.amountTextField = nil;
	self.enterButton = nil;
	self.imageView = nil;
}

- (void)dealloc {
	[tableView release];
	[totalAmoutLabel release];
	[amountTextField release];
	[enterButton release];
	[imageView release];
	[image release];
	[exclusions release];
	[paymentDelegate release];
	[numberFormatter release];
    [super dealloc];
}

//	テキストフィールドが入力状態になったら追加ボタンを利用できるようにする。
- (void)textFieldDidBeginEditing:(UITextField *)textField {
	enterButton.enabled = YES;
}

/*
	除外金追加
*/
-(void)add:(int)inAmount {
	if (inAmount == 0)
		return;
	if ([paymentDelegate respondsToSelector:@selector(paymentViewController:add:)]) {
		if (![paymentDelegate paymentViewController:self add:inAmount]) {
			//	追加不可
			return;
		}
	}
	[exclusions addObject:[NSNumber numberWithInt:inAmount]];
	NSArray* list = [NSArray arrayWithObject:[NSIndexPath indexPathForRow:0 inSection:0]];
	[self.tableView insertRowsAtIndexPaths:list withRowAnimation:UITableViewRowAnimationTop];
	[self calc];
}

/*
	入金ボタンが押された
	キーボードを隠し、amountTextFieldの金額を除外金配列に追加し、amountTextFieldは空にする。
	入金ボタンは操作不能にする。
*/
-(IBAction)enterAmount:(id)sender {
	[amountTextField resignFirstResponder];
	[self add:[amountTextField.text intValue]];
	amountTextField.text = nil;
	enterButton.enabled = NO;
}

/*
	テーブルセルの総数を返す
*/
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [exclusions count];
}

/*
	テーブルセルを返す
*/
- (UITableViewCell *)tableView:(UITableView *)inTableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    static NSString *ID = @"ExclusionAmoutCell";
    UITableViewCell *cell = [inTableView dequeueReusableCellWithIdentifier:ID];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:ID] autorelease];
    }
	NSNumber* number = [exclusions objectAtIndex:[exclusions count] - indexPath.row - 1];
	cell.textLabel.textAlignment = UITextAlignmentRight;
	cell.textLabel.text = [numberFormatter stringFromNumber:number];
    return cell;
}

/*
	削除変種対応
*/
- (void)tableView:(UITableView *)inTableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {    
    if (editingStyle == UITableViewCellEditingStyleDelete) {
		int index = [exclusions count] - indexPath.row - 1;
		if ([paymentDelegate respondsToSelector:@selector(paymentViewController:remove:)]) {
			if (![paymentDelegate paymentViewController:self remove:index]) {
				//	削除不可
				return;
			}
		}
		[exclusions removeObjectAtIndex:index];
        [inTableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationFade];
		[self calc];
    }   
}

/*
	編集モード変更
*/
- (void)setEditing:(BOOL)editing animated:(BOOL)animated {
	[super setEditing:editing animated:animated];
	[self.tableView setEditing:editing animated:animated];
}

/*
	スワイプによる削除モード突入にあわせ、自分を編集モードにする。
*/
- (void)tableView:(UITableView *)tableView 
	willBeginEditingRowAtIndexPath:(NSIndexPath *)indexPath {
	[super setEditing:YES animated:YES];
}

/*
	削除モード終了に合わせ、自分自身の編集モードを解除する。
*/
- (void)tableView:(UITableView *)tableView 
	didEndEditingRowAtIndexPath:(NSIndexPath *)indexPath {
	[super setEditing:NO animated:YES];
}

@end

/*
	UITextFieldを拡張。
	自分に触れられるとキーボードを表示/日表示する。
*/
@implementation XUITextField
- (void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event {
	if ([self isFirstResponder]) {
		[self resignFirstResponder];
	} else {
		[super touchesBegan:touches withEvent:event];
	}
}

@end
